/**
 * 共通JavaScript
 */
/**
 * JSON形式か判定する
 * @return true:JSON形式 false:JSON形式でない
 */
function isJSON(target) {
	if(target){
    	var str = target.replace(/\\./g, '@').replace(/"[^"\\\n\r]*"/g, '');
    	return (/^[,:{}\[\]0-9.\-+Eaeflnr-u \n\r\t]*$/).test(str);
	}else{
	}
}
/**
 * 全ての項目に反映する
 * @param string name 項目名。行番号部分は*で設定
 * @param string value 設定する値
 * @param boolean includeHidden 表示されていない(visible:hiddenである）項目も含めるかどうか true:含める
 * @param boolean includeDisabled 使用不可(disabled:trueである）項目も含めるかどうか true:含める
 * @return セレクタ文字列
 */
function applyAll(target,value,includeHidden,includeDisabled){
	var additional = ":visible";
	if(includeHidden){
		additional = "";
	}
	if(!includeDisabled){
		additional = "[disabled!=true]"+additional;
	}
	var selecter = "";
	selecter = getInputSelecter(target,additional);
	$(selecter).val(value);
	$(selecter).css('background-image','none');
}
/**
 * 入力項目のjqueryセレクタを取得する
 * @param string name 項目名。行番号部分は*で設定
 * @param string additional セレクタに追加する設定
 * @return セレクタ文字列
 */
function getInputSelecter(name,additional){
	name = domId(name);
	var name1;
	var name2;
	var idx = name.indexOf("*");
	var selecter = "";
	if(idx>=0){
		name1 = name.substr(0,idx);
		name2 = name.substr(idx+1);
		selecter = "input[id^='"+name1+"'][id*='"+name2+"']"+additional+",select[id^='"+name1+"'][id*='"+name2+"']"+additional;
	}else{
		selecter = "input[id='"+name+"']"+additional+",select[id='"+name+"']"+additional;
	}
	return selecter;
}
/**
 * Cakeが作成した名前(name属性)から、インデックス(行番号)を取得する
 * @param string name 項目名。Cakeが作成した名前(name属性)
 * @return インデックス(行番号)
 */
function getIndexByCakeName(name){
	var nameparts;
	nameparts = name.replace(/]/g,'');
	nameparts = nameparts.split("[");
	for(var i=0;i<nameparts.length;i++){
		if(!isNaN(nameparts[i])){
			return nameparts[i];
		}
	}
	return false;
}
/**
 * 項目名からCakeが作成する名前(name属性)を取得する
 * @param string name 項目名
 * @param string method メソッド（get/post 未設定時はpost)
 * @return Cakeが作成する名前(name属性)
 */
function getCakeNameByName(name,method){
	if(!method||method==""){
		method = "post";
	}
	if(method == "get"){
		return getCakeNameByNameGet(name);
	}else{
		return getCakeNameByNamePost(name);
	}
}

function getCakeNameByNamePost(name){
	var nameparts;
	nameparts = name.split(".");
	var cakeName = "";
	for(var i = 0; i < nameparts.length ; i++){
		cakeName = cakeName + '[' + nameparts[i] + ']';
	}
	cakeName = 'data' + cakeName;
	return cakeName;
}
function getCakeNameByNameGet(name){
	var nameparts;
	nameparts = name.split(".");
	var cakeName = "";
	for(var i = 1; i < nameparts.length ; i++){
		if(i=1){
			cakeName = cakeName + nameparts[i];
		}else{
			cakeName = cakeName + '[' + nameparts[i] + ']';
		}
	}
	return cakeName;
}
function ucfirst(match){
	  return match.replace(/^[a-z]/i, function(match) { return match.toUpperCase(); });
}
/**
 * 読み取り専用切替
 * @param string name 項目名。行番号部分は*で設定
 * @param boolean readOnry true:読み取り専用にする false:入力可にする
 * ※textにしか設定できません！
 */
function changeReadOnly(name,readOnly){
	name = domId(name);
	var name1;
	var name2;
	var idx = name.indexOf("*");
	var target = "";
	if(idx>=0){
		name1 = name.substr(0,idx);
		name2 = name.substr(idx+1);
		target = "input[id^='"+name1+"'][id*='"+name2+"'][type!=hidden],select[id^='"+name1+"'][id*='"+name2+"']";
	}else{
		target = "input[id^='"+name+"'][type!='hidden'],select[id^='"+name+"']";
	}

	if(readOnly){
		$(target).attr("readOnly",readOnly);
		$(target).attr("tabindex",'-1');
		$(target).addClass("decide");
	}else{
		$(target).removeAttr("readOnly");
		$(target).removeClass("decide");
		$(target).removeAttr("tabindex");
		//以下IE用
		var elements = $(target).get();
		for(i=0;i<elements.length;i++){
			document.getElementById(elements[i].id).readOnly = false;
		}
	}
	if($(target).datepicker){
		$(target).datepicker("option","disabled",readOnly);
		$(target).datepicker("option","showOn",readOnly?"focus":"both");
	}
}
/**
 * 入力可・不可切替
 * @param string name 項目名。行番号部分は*で設定
 * @param boolean disabled true:入力不可にする false:入力可にする
 */
function changeDisable(name,disabled){
	name = domId(name);
	var name1;
	var name2;
	var idx = name.indexOf("*");
	var target = "";
	if(idx>=0){
		name1 = name.substr(0,idx);
		name2 = name.substr(idx+1);
		target = "input[id^='"+name1+"'][id*='"+name2+"'][type!=hidden],select[id^='"+name1+"'][id*='"+name2+"']";
	}else{
		target = "input[id^='"+name+"'][type!='hidden'],select[id^='"+name+"']";
	}

	if(disabled){
		$(target).attr("disabled",disabled);
		$(target).addClass("decide");
	}else{
		$(target).removeAttr("disabled");
		$(target).removeClass("decide");
		//以下IE用
		var elements = $(target).get();
		for(i=0;i<elements.length;i++){
			document.getElementById(elements[i].id).disabled = true;
			document.getElementById(elements[i].id).disabled = false;
		}
	}
	if($(target).datepicker){
		$(target).datepicker("option","disabled",disabled);
		$(target).datepicker("option","showOn",disabled?"focus":"both");
	}
}
/**
 * 表示・非表示切替
 * @param string name 項目名。行番号部分は*で設定
 * @param boolean visible true:表示 false:非表示
 */
function changeVisible(name,visible){
	name = domId(name);
	var name1;
	var name2;
	var idx = name.indexOf("*");
	var target = "";
	if(idx>=0){
		name1 = name.substr(0,idx);
		name2 = name.substr(idx+1);
		target = "input[id^='"+name1+"'][id*='"+name2+"'][type!=hidden],select[id^='"+name1+"'][id*='"+name2+"'],label[for^='"+name1+"'][for*='"+name2+"']";
	}else{
		target = "input[id^='"+name+"'][type!='hidden'],select[id^='"+name+"'],label[for^='"+name+"']";
	}

	if(visible){
		$(target).attr('style','visibility:visible');
	}else{
		$(target).attr('style','visibility:hidden');
		//以下IE用
		var elements = $(target).get();
		for(i=0;i<elements.length;i++){
			if(elements[i].id){
				document.getElementById(elements[i].id).visibility = "hidden";
			}
		}
	}
	if($(target).datepicker){
		$(target).datepicker("option","showOn",visible?"both":"focus");
	}
}
/**
 * 項目クリア
 * @param string name 項目名。行番号部分は*で設定すると複数項目に設定可
 */
function clearValue(name){
	name = domId(name);
	var name1;
	var name2;
	var idx = name.indexOf("*");
	if(idx>=0){
		name1 = name.substr(0,idx);
		name2 = name.substr(idx+1);
		$("input[id^='"+name1+"'][id*='"+name2+"']").val("");
	}else{
		$("input[id='"+name+"']").val("");
	}
}
/**
 * 画面内の項目全有効化
 */
function changeAllEnable(){
	$(":input[type!=hidden]").attr("disabled",false);
	//以下IE用
	var elements = $(":input[type!=hidden]").get();
	for(i=0;i<elements.length;i++){
		if(elements[i].id){
			document.getElementById(elements[i].id).disabled = true;
			document.getElementById(elements[i].id).disabled = false;
		}
	}
}
/**
 * チェックボックス選択・未選択切替
 * @param string name 項目名またはクラス名。項目名の場合、行番号部分は*で設定
 * @param boolean on true:選択する false:選択解除する
 * @param string type 'class' チェックボックス選択方法がcssクラス 'id' チェックボックス選択方法がid(項目名）
 */
function changeChk(name,on,type){
	if(type === 'class'){
		if(on){
			$("."+name).attr("checked","checked");
		}else{
			$("."+name).removeAttr("checked");
		}
	}else{
		name = domId(name);
		var name1;
		var name2;
		var idx = name.indexOf("*");
		if(idx>=0){
			name1 = name.substr(0,idx);
			name2 = name.substr(idx+1);
			if(on){
				$("input[id^='"+name1+"'][id$='"+name2+"']").attr("checked","checked");
			}else{
				$("input[id^='"+name1+"'][id$='"+name2+"']").removeAttr("checked");
			}
		}else{
			if(on){
				$("input[id='"+name+"']").attr("checked","checked");
			}else{
				$("input[id='"+name+"']").removeAttr("checked");
			}
		}
	}
}
/**
 * 項目名からCAKEで作成されたDOMのIDを取得する
 * @param string name 項目名
 * @return DOMのID
 */
function domId(name){
	name = name.replace(/\../g,function(matched){return matched.charAt(1).toUpperCase();});
	name = name.replace(/_./g,function(matched){return matched.charAt(1).toUpperCase();});
	return name;
}
/**
 * JSON文字列からJavaScriptオブジェクトを作成する
 * @param string target JSON文字列
 * @return JavaScriptオブジェクト
 */
function jsonToObject(target){
	if(target instanceof Object){
	}else{
		if(target){
		if(isJSON(target)){
			target = (new Function("return "+target))();
		}else{
			if(isConfigDebug()){
				alert("JSON形式ではありません\n"+target);
			}
			target = {message:"JSON形式ではありません\n"+target};
		}
	}
	}
	return target;
}
/**
 * 指定の項目の全値を結合する
 * @param array items 指定の項目IDの配列
 * @param string separetor 結合時のセパレータ
 * @return 指定の項目の全値を結合した文字列
 */
function getConcatAllValue(items,separetor){
	var value = "";
	for(var i=0;i<items.length;i++){
		var addVal =  $("#"+items[i]).val();
		if(i>0 && value!= "" && addVal!=""){
			value = value + separetor;
		}
		value = value + addVal;
	}
	return value;
}
/**
 * リストボックスから選択した項目を移動させる
 * @param string fromId 移動元リストのID
 * @param string toId 移動先リストのID
 * @param boolean isRemoveFrom 移動元リストから削除するか
 * @param boolean isSameAdd 移動先に同じ項目があった場合も追加するか
 */
function moveSelectList(fromId,toId,isRemoveFrom,isSameAdd){
	var selected = $("#"+fromId).get();
	if(selected[0]){
		selected = selected[0];
	}
	var to = $("#"+toId).get();
	if(to[0]){
		to = to[0];
	}
	var remove = new Array();
	for(var i=0;i<selected.options.length;i++){
		if(selected.options[i].selected){
			var noAdd = false;
			if(!isSameAdd){
				for(var n=0;n<to.options.length;n++){
					if(to.options[n].value == selected.options[i].value){
						noAdd = true;
						break;
					}
				}
			}
			if(isRemoveFrom){
				remove.push(selected.options[i].value);
			}
			if(noAdd){
				continue;
			}
			var option = new Option();
			option.value = selected.options[i].value;
			option.text = selected.options[i].text;
			to.options[to.options.length] = option;
		}
	}
	for(var i=0;i<remove.length;i++){
		for(var n=0;n<selected.options.length;n++){
			if(remove[i] == selected.options[n].value){
				selected.remove(n);
			}
		}
	}
}
/**
 * フロー表示
 * @param array flows 表示するフロー表示文字配列
 * @param int current flowで現在のフローの番号
 */
function setFlow(flows,current){
	var flowHtml = "";
	flowHtml = flowHtml + '<ul class="cont-flow-title">';
	for(var i=0;i<flows.length;i++){
		var clazz = "";
		if(i==flows.length-1){
			clazz = clazz + "last";
		}
		if(i==current){
			if(clazz != ""){
				clazz = clazz + " ";
			}
			clazz = clazz + "current";
		}
		flowHtml = flowHtml + '<li class="'+clazz+'"><span>'+flows[i]+'</span></li>';
	}
	flowHtml = flowHtml + "</ul>";
	$('#cont-box-title').html(flowHtml);
}

/**
 * タイトル表示変更
 * @param string title タイトルに設定する文字
 * @param string additional タイトルに追記するもの(htmlも可)
 */
function setTitle(title,additional){
	$('#contents-title h1').html(title);
	if(additional){
		$('#contents-title h1').append(additional);
	}
}
/**
 * タイトルアイコン表示
 * @param string clazz タイトルに追加するクラス
 */
function setTitleIcon(clazz){
	$('#contents-title').addClass(clazz);
}
/**
 * 電話番号設定
 * @param string telNo 設定する電話番号
 * @param string telNoName 電話番号項目名
 */
function setTelNo(telNo,telNoName){
	var id = domId(telNoName);
	var tel1id = id + "1";
	var tel2id = id + "2";
	var tel3id = id + "3";
	$("#"+id).val(telNo);
	var telNos = telNo.split("-");
	$("#"+tel1id).val(telNos[0]);
	$("#"+tel2id).val(telNos[1]);
	$("#"+tel3id).val(telNos[2]);
}
/**
 * 郵便番号設定
 * @param string zipNo 設定する郵便番号
 * @param string zipNoName 郵便番号項目名
 */
function setZip(zipNo,zipNoName){
	var zipid = domId(zipNoName);
	var zip3id = zipid + "3";
	var zip4id = zipid + "4";

	$('#'+zipid).val(zipNo);
	$('#'+zip3id).val(zipNo.substr(0,3));
	$('#'+zip4id).val(zipNo.substr(3));
}
/**
 * 入力文字数制御設定
 */
function loadInputPreview(){
	var items = ['Obwua02010formDirectInfoDirectAddress1','Obwua02010formDirectInfoDirectAddress2','Obwua02010formDirectInfoDirectAddress3'];
	var separator = "";
	var value = getConcatAllValue(items,separator);
	$("#address_preview").html(value);
	var valuelength = value.length - (separator.length * (items.length-1));
	if(valuelength<=45){
		$("#address_preview_exp").html("あと"+(45-valuelength)+"文字入力できます。");
	}else{
		$("#address_preview_exp").html(valuelength + "文字入力されています。45文字以下で入力してください。");
	}
}

/**
 * 行しましま設定
 * @param int rownum 1レコードの行数
 * @param int startrow 開始行数 未設定時は1レコード分の行数が設定されます。ヘッダ行も同じテーブルの場合、かつレコード行と行数が異なる場合に設定してください
 * @param int interval 間隔行数 一覧の間にもヘッダ行が入る場合、かつ$startrow設定時に設定します
 */
function setRowSplite(rownum,startrow,interval){
	var r = 0;
	if(startrow == null){
		startrow = rownum;
	}
	var rowcount = $("#list-table table tr").get().length;
	if(interval == null){
		interval = rowcount;
	}
	var intervalCount = 0;
	for(var i = 0;i<rowcount;i++){
		intervalCount = Math.floor(rowcount/(startrow + rownum * interval));
		r = Math.floor((i-(startrow*intervalCount))/rownum);
		if((startrow * intervalCount)+(rownum*interval*intervalCount)<i && i<((startrow * intervalCount)+(rownum*interval*intervalCount)+startrow)){
			continue;
		}
		if(r%2 == 0){
			//$("#list-table table tr:eq("+i+")").addClass("evenrow");
			$("#list-table table tr:eq("+i+")").attr('style','background-color:#DFDFFF;');
		}else{
			//$("#list-table table tr:eq("+i+")").removeClass("evenrow");
			$("#list-table table tr:eq("+i+")").attr('style','background-color:white;');
		}
	}
}

/**
 * 日付の妥当性チェック
 * year 年
 * month 月
 * day 日
 */
function checkDate(year, month, day) {
	var dt = new Date(year, month - 1, day);
	if(dt == null || dt.getFullYear() != year || dt.getMonth() + 1 != month || dt.getDate() != day) {
		return false;
	}
	return true;
}

/**
 * 年月日と加算日からn日後、n日前を求める関数
 * year 年
 * month 月
 * day 日
 * addDays 加算日。マイナス指定でn日前も設定可能
 */
function computeDate(year, month, day, addDays) {
    var dt = new Date(year, month - 1, day);
    var baseSec = dt.getTime();
    var addSec = addDays * 86400000;//日数 * 1日のミリ秒数
    var targetSec = baseSec + addSec;
    dt.setTime(targetSec);
    return dt;
}
/**
 * 年月を指定して月末日を求める関数
 * year 年
 * month 月
 */
function getMonthEndDay(year, month) {
    //日付を0にすると前月の末日を指定したことになります
    //指定月の翌月の0日を取得して末日を求めます
    //そのため、ここでは month - 1 は行いません

    var dt = new Date(year, month, 0);
    return dt.getDate();
}
/**
 * 年月日と加算月からnヶ月後、nヶ月前の日付を求める
 * year 年
 * month 月
 * day 日
 * addMonths 加算月。マイナス指定でnヶ月前も設定可能
 */
function computeMonth(year, month, day, addMonths) {
    month += addMonths;
    var endDay = getMonthEndDay(year, month);
    if(day > endDay) day = endDay;
    var dt = new Date(year, month - 1, day);
    return dt;
}
function addDay(target,addDay){
	var dt = null;
	if(target instanceof Date){
		dt = target;
	}else{
		dt = convDate(target);
	}
	if(dt){
		return conputeDate(dt.getFullYear(),dt.getMonth()+1,dt.getDate(),addDay);
	}else{
		return false;
	}
}

function addMonth(target,addMonth){
	var dt = null;
	if(target instanceof Date){
		dt = target;
	}else{
		dt = convDate(target);
	}
	if(dt){
		return computeMonth(dt.getFullYear(),dt.getMonth()+1,dt.getDate(),addMonth);
	}else{
		return false;
	}
}
function convDate(target){
	var year = 9999;
	var month = 99;
	var day = 99;
	if(target.length == 8){
		year = target.substring(0,4);
		month = target.substr(4,2);
		day = target.substr(6,2);
	}else{
		var parts = null;
		target = target.replace("-","/");
		target = target.replace(".","/");
		target = target.replace(":","/");
		target = target.replace(" ","/");
		if(target.indexOf("/")>0){
			parts = target.split("/");
		}
		if(parts.length>=3){
			year = parts[0];
			month = parts[1];
			day = parts[2];
		}
	}
	if(checkDate(year,month,day)){
		var dt = new Date(year, month - 1, day);
		return dt;
	}else{
		return false;
	}
}

function compareDate(target1,target2){
	if(target1 == null && target2!= null){
		return -1;
	}
	if(target1 != null && target2 == null){
		return 1;
	}
	if(target1 == null && target2 == null){
		return 0;
	}
	var dt1 = null;
	var dt2 = null;
	if(target1 instanceof Date){
		dt1 = target1;
	}else{
		dt1 = convDate(target1);
	}
	if(target2 instanceof Date){
		dt2 = target2;
	}else{
		dt2 = convDate(target2);
	}
	if(dt2 && dt2){
		if(dt1.getTime() < dt2.getTime()) {
			return -1;
		}else if(dt1.getTime() == dt2.getTime()) {
			return 0;
		} else {
			return 1;
		}
	}else{
		return null;
	}
}
/**
 * オーバーレイ設定
 */
function setOverlay(){
	$(".overlay").colorbox({
		innerWidth: "90%",
		innerHeight: "80%",
		iframe: true,
		opacity: "0.7",
		speed: 600,
		onComplete:function(){$('*').css('cursor','');},
		onOpen:function(){$('*').css('cursor','');}
	});
}
/**
 * メッセージ表示
 */
function alertMessage(msg,obj){
	alert(msg);
}

/**
 * 指定文字で始まっているかどうか
 */
function startWith(target,prefix){
	if(target.lastIndexOf(prefix,0)==0){
		return true;
	}else{
		return false;
	}
}
/**
 * 数値の値を取得する
 */
function intVal(target){
	if(isNaN(target)){
		return 0;
	}else{
		return target-0;
	}
}
/**
 * 品番ゆらぎ変換
 * 全角→半角(全角英数字→半角英数字）
 * 小文字→大文字
 * 空白除去
 * 全角ピリオド→半角ピリオド
 * 半角英数字+"."以外の文字を削除
 * @param string $target 品番文字列
 * @return 品番ゆらぎ変換後対象文字列
 */
function convArticleCd(target){

	if(target == null){
		return target;
	}
	str = "";
	for (lp=0;lp<target.length;lp++) {
		unicode=target.charCodeAt(lp);
		if ((0xff0f<unicode) && (unicode<0xff1a)) {
			str+=String.fromCharCode(unicode-0xfee0);
		}else if ((0xff20<unicode) && (unicode<0xff3b)) {
			str+=String.fromCharCode(unicode-0xfee0);
		}else if ((0xff40<unicode) && (unicode<0xff5b)) {
			str+=String.fromCharCode(unicode-0xfee0);
		}else {
			str+=String.fromCharCode(unicode);
		}
	}
	target = str;
	target = target.toUpperCase();
	target = target.replace(/^[ 　]+/,"").replace(/[ 　]+$/,"");
	target = target.replace("．", ".");
	//target = target.replace(/[^A-Z0-9ｦ-ﾟ\.]+/, "").replace(/[^A-Z0-9ｦ-ﾟ\.]+$/, "");
	target = target.replace(/[^A-Z0-9ｦ-ﾟ\.]/g, "");
	//target = target.replace(/-/g, "");
	target = target.replace(/[-―ー‐－]/g, "");
	return target;

}

/**
 * 発注コード変換
 * @param target 変換対象文字列
 * @returns 変換後のtarget
 */
function convPordCd(target){
	if(target == null){
		return target;
	}
//	target = target.replace("-", "");
	target = target.replace(/[-―ー‐－]/g, "");
	target = convNumHalf(target);
	return target;
}

/**
 * 全角数字を半角に変換
 * @param target 変換対象文字列
 * @returns 変換後のtarget
 */
function convNumHalf(target){
	return target.replace(/[０１２３４５６７８９]/g,function(arg){
		var idx = "０１２３４５６７８９".indexOf(arg);
		return (idx !== -1)?idx:arg;
	});
}
/**
 * 2重送信防止
 * content内のボタン・リンクを無効にします
 */
function submitChangeDisable(obj){
	$('#content input[type=button],#content input[type=image],#content input[type=submit],#content button').attr('disabled',true);
	$('#content a').click(function(event){return false;});
}

/**
 * 現在の画面のプロトコルがhttpsならば、httpsに、httpならば,httpにします
 */
function replaceHttps(url){
	if(url){
		if(document.URL.substr(0,8)=="https://"){
			url = url.replace("http://","https://");
		}else if(document.URL.substr(0,7)=="http://"){
			url = url.replace("https://","http://");
		}
		return url;
	}else{
		return null;
	}
}

/**
 * リンクを押せなくします
 */
function setLinkDisable(name,disabled){
	var id = domId(name);
	var disableid = id+"disable";
	if(disabled){
		if($("#"+disableid).get()>0){
			$("#"+disableid).show();
		}else{
			var p = $("#"+id).position();
			var cover = '';
			if(jQuery.browser.msie){
				cover = 'background-color:black;filter:Alpha(opacity:1);';
			}else{
				cover = 'background-color:transparent;';
			}
			$("#"+id).after("<div id='"+id+"disable"+"' style='z-index:1000;position:absolute;top:"+p.top+"px;left:"+p.left+"px;width:"+($("#"+id).width()+4)+"px;height:"+$("#"+id).height()+"px;"+cover+"'></div>");

		}
	}else{
		$("#"+id+"disable").hide();
	}
}

function isIE(){
	var browser = getBrowser();
	if(startWith(browser,"ie")){
		return true;
	}
	return false;
}

function getBrowser(){
	var _ua = (function(){
		return {
			ltIE6:typeof window.addEventListener == "undefined" && typeof
			document.documentElement.style.maxHeight == "undefined",
			ltIE7:typeof window.addEventListener == "undefined" && typeof
			document.querySelectorAll == "undefined",
			ltIE8:typeof window.addEventListener == "undefined" && typeof
			document.getElementsByClassName == "undefined",
			IE:document.uniqueID,
			Firefox:window.sidebar,
			Opera:window.opera,
			Webkit:!document.uniqueID && !window.opera && !window.sidebar &&
			window.localStorage && typeof window.orientation == "undefined",
			Mobile:typeof window.orientation != "undefined"
			}
	})();
	if(_ua.ltIE6){
		//あなたがお使いのブラウザはIE6以下です
		return "ie6";
	}else if(_ua.ltIE7){
		//あなたがお使いのブラウザはIE7以下です
		return "ie7";
	}else if(_ua.ltIE8){
		//document.write('あなたがお使いのブラウザはIE8以下です
		return "ie8";
	}else if(_ua.webkit){
		//あなたがお使いのブラウザはchromeもしくはsafariです
		return "chrome or safari";
	}else if(_ua.Firefox){
		//あなたがお使いのブラウザはFirefoxです
		return "firefox";
	}else if(_ua.Opera){
		//あなたがお使いのブラウザはOperaです'
		return "opera";
	}else if(_ua.IE && !_ua.ltIE8){
		//あなたがお使いのブラウザはIE9以上です'
		return "ie9";
	}else if(_ua.Mobile){
		//あなたはスマートフォンとかタブレット端末です
		return "tablet";
	}

}

/**
 * 正式品番とオプションコードを連結します
 * @param formalArticle
 * @param optionCd
 * @returns
 */
function concatFormalArticle(formalArticle,optionCd){
	var ret = formalArticle + (new Array(30).join(" ")).slice(30);
	ret = formalArticle + optionCd;
	return ret;
}